function [A3, b3, ctype3] = MBKS_zostav_obmedzenie_typ3(n, m, z, pocet_neznamych_celkom, w, max_wknd_den, weekend_indx) 
% Funkcia pre zostavenie subcasti matice obmedzeni A, subcasti vektoru
% pravych stran b a subcasti vektoru znakov ctype pre tretie zavazne
% obmedzenie
% 
% Volanie
%   [A3, b3, ctype3] = MBKS_zostav_obmedzenie_typ3(n, m, z, pocet_neznamych_celkom, w, max_wknd_den, weekend_indx)
% Vstup:
%   n - pocet sestier
%   m - pocet dni planovaneho obdobia
%   z - pocet smien
%   pocet_neznamych_celkom - celkovy pocet neznamych pre zavazne aj nezavazne poziadavky
%   w - pocet vikendovych dni za periodu m
%   max_wknd_den - max pocet vikendovych pracovnych dni za periodu m
%   weekedn_indx - indexy vikendovych smien
% Výstup:
%   A3 - subcast matice obmedzeni A
%   b3 - subcast vektoru pravych stran b
%   ctype3 - subcast vektoru znakov ctype
%% ABOUT
% Funkcia MBKS_zostav_obmedzenie_typ3 si zavola vstupne premenne zo
% skriptu MBKS_vstupne_parametre. Jej vystupy budu predstavovat cast matice
% ombedzeni A, vektoru pravych stran b, a parametru ctype. 
%
% Na zaciatku si zadeklarujeme premenne pocet_obmedzeni a
% pocet_nenulovych_prvkov, potrebnych pre urcenie velkosti casti matice
% obmedzeni A3, casti vektoru pravych stran b3 a casti parametru ctype3
%
% Pomocou funkcie salloc sa allokuje A3 a nasledne pomocou sustavy
% vnorenych cyklov typu for sa bude A3 naplnat. Maticu A3 sa naplna
% postupnym prechadzanim kazdeho riadku cr a k nemu odpovedajucih stlpcov.
%
% Na zaver sa naplni cast vektoru pravych stran b3 a zvoli vhodna hodnota
% parametru ctype3

%% Deklarovanie parametrov
pocet_obmedzeni = n; 
pocet_nenulovych_prvkov = m * z * pocet_obmedzeni;

%% Inicializacia casti matice obmedzeni A3
A3 = spalloc(pocet_obmedzeni, pocet_neznamych_celkom, pocet_nenulovych_prvkov);
b3 = ones(pocet_obmedzeni, 1) * (w - max_wknd_den);

%% Naplnenie casti matice obmedzeni A3
cr = 1; % Cislo 1. riadku matice
for i = 1:n
    for j = weekend_indx
        for k = 1:z
            A3(cr, i + (j - 1) * n + (k - 1) * m * n) = 1;
        end
    end
    cr = cr + 1; % Posun na dalsi riadok matice
end

%% Naplnenie casti vektoru pravych stran b3 a casti parametru ctype3
b3 = ones(pocet_obmedzeni, 1) * (w - max_wknd_den); % Naplnenie casti vektoru pravych stran b3
ctype3(1:pocet_obmedzeni) = 'U'; % v obmedzeniach sa objavuju nerovnosti <=, preto hodnota U

end